@@ -1,9 +1,16 @@
-rmatrix <- function(nrow, ncol, mode=c("double", "integer"), range=c(-100,+100), naProb=0) {
+rmatrix <- function(nrow, ncol, mode=c("logical", "double", "integer", "index"), range=c(-100,+100), naProb=0) {
   mode <- match.arg(mode)
   n <- nrow*ncol
-  X <- runif(n, min=range[1], max=range[2])
-  if (naProb > 0) X[sample(n, size=naProb*n)] <- NA_real_
+  if (mode == "logical") {
+    X <- sample(c(FALSE, TRUE), size=n, replace=TRUE)
+  } else if (mode == "index") {
+    X <- seq_len(n)
+    mode <- "integer";
+  } else {
+    X <- runif(n, min=range[1], max=range[2])
+  }
   storage.mode(X) <- mode
+  if (naProb > 0) X[sample(n, size=naProb*n)] <- NA
   dim(X) <- c(nrow, ncol)
   X
 } # rmatrix()
@@ -25,6 +32,8 @@ rmatrices <- function(scale=10, seed=1, ...) {
 
 ############################################################################
 # HISTORY:
+# 2014-11-09
+# o Added 'index' mode.
 # 2014-06-02
 # o Created.
 ############################################################################
