@@ -22,58 +22,69 @@ rowRanges_R <- function(x, ...) {
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # With and without some NAs
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-for (addNA in c(FALSE, TRUE)) {
-  cat("addNA=", addNA, "\n", sep="")
+for (mode in c("integer", "double")) {
+  cat("mode: ", mode, "\n", sep="")
 
-  x <- matrix(1:100, nrow=20, ncol=5)
-  if (addNA) {
-    x[13:17,c(2,4)] <- NA_real_
-  }
-  str(x)
+  for (addNA in c(FALSE, TRUE)) {
+    cat("addNA=", addNA, "\n", sep="")
 
-  # Row/column extremes
-  for (na.rm in c(FALSE, TRUE)) {
-    cat("na.rm=", na.rm, "\n", sep="")
+    x <- matrix(1:100+0.1, nrow=20, ncol=5)
+    if (addNA) {
+      x[13:17,c(2,4)] <- NA_real_
+    }
+    storage.mode(x) <- mode
+    str(x)
 
-    # Ranges
-    cat("range:\n")
-    r0 <- rowRanges_R(x, na.rm=na.rm)
-    r1 <- rowRanges(x, na.rm=na.rm)
-    r2 <- colRanges(t(x), na.rm=na.rm)
-    stopifnot(all.equal(r1, r2))
-    stopifnot(all.equal(r1, r0))
+    # Row/column extremes
+    for (na.rm in c(FALSE, TRUE)) {
+      cat("na.rm=", na.rm, "\n", sep="")
 
-    # Min
-    cat("min:\n")
-    m0 <- rowMins_R(x, na.rm=na.rm)
-    m1 <- rowMins(x, na.rm=na.rm)
-    m2 <- colMins(t(x), na.rm=na.rm)
-    stopifnot(all.equal(m1, m2))
-    stopifnot(all.equal(m1, m0))
+      # Ranges
+      cat("range:\n")
+      r0 <- rowRanges_R(x, na.rm=na.rm)
+      r1 <- rowRanges(x, na.rm=na.rm)
+      r2 <- colRanges(t(x), na.rm=na.rm)
+      stopifnot(all.equal(r1, r2))
+      stopifnot(all.equal(r1, r0))
 
-    # Max
-    cat("max:\n")
-    m0 <- rowMaxs_R(x, na.rm=na.rm)
-    m1 <- rowMaxs(x, na.rm=na.rm)
-    m2 <- colMaxs(t(x), na.rm=na.rm)
-    stopifnot(all.equal(m1, m2))
-    stopifnot(all.equal(m1, m0))
-  }
-} # for (addNA ...)
+      # Min
+      cat("min:\n")
+      m0 <- rowMins_R(x, na.rm=na.rm)
+      m1 <- rowMins(x, na.rm=na.rm)
+      m2 <- colMins(t(x), na.rm=na.rm)
+      stopifnot(all.equal(m1, m2))
+      stopifnot(all.equal(m1, m0))
+
+      # Max
+      cat("max:\n")
+      m0 <- rowMaxs_R(x, na.rm=na.rm)
+      m1 <- rowMaxs(x, na.rm=na.rm)
+      m2 <- colMaxs(t(x), na.rm=na.rm)
+      stopifnot(all.equal(m1, m2))
+      stopifnot(all.equal(m1, m0))
+    }
+  } # for (addNA ...)
+} # for (mode ...)
 
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # All NAs
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-x <- matrix(NA_real_, nrow=20, ncol=5)
-for (na.rm in c(FALSE, TRUE)) {
-  cat("na.rm=", na.rm, "\n", sep="")
-  r0 <- rowRanges_R(x, na.rm=na.rm)
-  r1 <- rowRanges(x, na.rm=na.rm)
-  r2 <- colRanges(t(x), na.rm=na.rm)
-  stopifnot(all.equal(r1, r2))
-  stopifnot(all.equal(r1, r0))
-}
+for (mode in c("integer", "double")) {
+  cat("mode: ", mode, "\n", sep="")
+  x <- matrix(NA_real_, nrow=20, ncol=5)
+  storage.mode(x) <- mode
+  str(x)
+
+  for (na.rm in c(FALSE, TRUE)) {
+    cat("na.rm=", na.rm, "\n", sep="")
+    r0 <- rowRanges_R(x, na.rm=na.rm)
+    r1 <- rowRanges(x, na.rm=na.rm)
+    r2 <- colRanges(t(x), na.rm=na.rm)
+    stopifnot(all.equal(r1, r2))
+    stopifnot(all.equal(r1, r0))
+  }
+} # for (mode ...)
 
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
