@@ -5,29 +5,45 @@ set.seed(1)
 x <- matrix(rnorm(20), nrow=5, ncol=4)
 print(x)
 
-# Non-weighted row averages
+# Non-weighted row medians
 xM0 <- rowMedians(x)
-xM <- rowWeightedMedians(x)
-stopifnot(all.equal(xM, xM0))
+xM1 <- rowWeightedMedians(x)
+stopifnot(all.equal(xM1, xM0))
+xM2 <- colWeightedMedians(t(x))
+stopifnot(all.equal(xM2, xM0))
 
-# Weighted row averages (uniform weights)
+# Weighted row medians (uniform weights)
 w <- rep(2.5, ncol(x))
-xM <- rowWeightedMedians(x, w=w)
-stopifnot(all.equal(xM, xM0))
+xM1 <- rowWeightedMedians(x, w=w)
+stopifnot(all.equal(xM1, xM0))
+xM2 <- colWeightedMedians(t(x), w=w)
+stopifnot(all.equal(xM2, xM0))
 
-# Weighted row averages (excluding some columns)
+# Weighted row medians (excluding some columns)
 w <- c(1,1,0,1)
 xM0 <- rowMedians(x[,(w == 1),drop=FALSE])
-xM <- rowWeightedMedians(x, w=w)
-stopifnot(all.equal(xM, xM0))
+xM1 <- rowWeightedMedians(x, w=w)
+stopifnot(all.equal(xM1, xM0))
+xM2 <- colWeightedMedians(t(x), w=w)
+stopifnot(all.equal(xM2, xM0))
 
-# Weighted row averages (excluding some columns)
+# Weighted row medians (excluding some columns)
 w <- c(0,1,0,0)
 xM0 <- rowMedians(x[,(w == 1),drop=FALSE])
-xM <- rowWeightedMedians(x, w=w)
-stopifnot(all.equal(xM, xM0))
+xM1 <- rowWeightedMedians(x, w=w)
+stopifnot(all.equal(xM1, xM0))
+xM2 <- colWeightedMedians(t(x), w=w)
+stopifnot(all.equal(xM2, xM0))
 
-# Weighted averages by rows and columns
+# Weighted row medians (all zero weights)
+w <- c(0,0,0,0)
+xM0 <- rowMedians(x[,(w == 1),drop=FALSE])
+xM1 <- rowWeightedMedians(x, w=w)
+stopifnot(all.equal(xM1, xM0))
+xM2 <- colWeightedMedians(t(x), w=w)
+stopifnot(all.equal(xM2, xM0))
+
+# Weighted medians by rows and columns
 w <- 1:4
 xM1 <- rowWeightedMedians(x, w=w)
 xM2 <- colWeightedMedians(t(x), w=w)
@@ -37,12 +53,14 @@ stopifnot(all.equal(xM2, xM1))
 # Weighted row medians with missing values
 xM0 <- apply(x, MARGIN=1, FUN=weightedMedian, w=w, na.rm=TRUE)
 print(xM0)
-xM <- rowWeightedMedians(x, w=w, na.rm=TRUE)
-print(xM)
-stopifnot(all.equal(xM, xM0))
+xM1 <- rowWeightedMedians(x, w=w, na.rm=TRUE)
+print(xM1)
+stopifnot(all.equal(xM1, xM0))
+xM2 <- colWeightedMedians(t(x), w=w)
+stopifnot(all.equal(xM2, xM0))
 
 # Weighted medians by rows and columns
 w <- 1:4
 xM1 <- rowWeightedMedians(x, w=w, na.rm=TRUE)
 xM2 <- colWeightedMedians(t(x), w=w, na.rm=TRUE)
-stopifnot(all.equal(xM2, xM1)) 
\ No newline at end of file
+stopifnot(all.equal(xM2, xM1))
